# == Class: wp_apache_nfs
#
# Module de déploiement d'une instance CloudStack by Ikoula avec Apache, NFS Client et montage d'une installation de Wordpress dernière version. A utiliser avec le module wp_mysql_nfs pour avoir l'instance MySQL et l'export de Wordpress.
#
# === Parameters
#
# Les paramètres pour ce script se résume à l'adresse ip de l'instance mysql/wordpress à utiliser qui est demandé à l'utilisateur via le script de déploiement PHP/API en userdata suivant :
# https://raw.github.com/ikoula/cloudstack/master/wp_apache_nfs.php
#
# === Authors
#
# Laurent H. Ikoula <contribATikoula.com>
#
# === Copyright
#
# Copyright 2013 Ikoula.
#

#
class apache::install {
    case $::operatingsystem {
        'CentOS': {
            $apache_name = 'httpd'
        }
        'Fedora': {
            $apache_name = 'httpd'
        }
	'OpenSuSE': {
            $apache_name = 'apache2'
        }

	'Debian': {
            $apache_name = 'apache2'
        }
	'Ubuntu': {
            $apache_name = 'apache2'
        }

        default: {
            $apache_name = 'apache2'
        }
    }

    # Installation du paquet Apache :
    package { "$apache_name":
        ensure => present,
        alias  => "apache",
	}
}
class apache::vhost {
	file { "/etc/apache2/sites-available/default":
        replace  => "true",
        source => "/etc/puppet/modules/wp_apache_nfs/files/etc.apache2.sites-available.default",
        owner   => root,
        group   => root,
        require => Package['apache'],
        mode    => 0644
	}
}
class php::install {
	case $::operatingsystem {
        'CentOS': {
            $php_name = 'php'
        }
	'Fedora': {
            $php_name = 'php'
        }
	'OpenSuSE': {
            $php_name = 'apache2-mod_php5'
        }
	'Debian': {
            $php_name = 'libapache2-mod-php5'
        }

        'Ubuntu': {
            $php_name = 'libapache2-mod-php5'
        }
        default: {
            $php_name = 'libapache2-mod-php5'
        }
    }

    # Installation du paquet Php comprenant le module pour Apache :
    package { "$php_name":
        ensure => present,
        require => Package ['apache']
        }
}
class phpmysql::install {
	package { "php5-mysql":
	ensure => present,
	}
}
class apache::service {
	 case $::operatingsystem {
        	'CentOS': {
            	$apache_service = 'httpd'
        	}
		'Fedora': {
                $apache_service = 'httpd'
                }
		'OpenSuSE': {
                $apache_service = 'apache2'
                }
        	'Debian': {
            	$apache_service = 'apache2'
        	}
		'Ubuntu': {
                $apache_service = 'apache2'
                }
        	default: {
            	$apache_service  = 'apache2'
        	}
    	}
	#On s'assure que le service Apache est en cours d'exécution/activé :        
	service { "$apache_service" :
                        ensure     => running,
                        enable     => true,
                        require    => [Class["apache::install"],
					Class["apache::vhost"],
					]
        }
}
class nfs::mount {
	package { 'nfs-common':
		ensure => present
	}
	exec { 'mkdir /var/www/wordpress && echo "`awk \'{print $1}\' /tmp/nfsserver`:/opt/wordpress /var/www/wordpress nfs rw 0 0" >> /etc/fstab && mount /var/www/wordpress && rm -f /tmp/nfsserver':
		logoutput => on_failure,
		path => ["/bin/", "/sbin/", "/usr/bin/"],
		require => [Package['nfs-common'],
				Class["apache::service"],
			]
	}
}
class apache::restart {
	exec { '/etc/init.d/apache2 restart':
		require => Class["nfs::mount"],
	}
}
#On appel toutes nos class avec la class globale Apache
class wp_apache_nfs {
        include apache::install, apache::service, apache::vhost, php::install, phpmysql::install, nfs::mount, apache::restart
}
